@@ -10,7 +10,11 @@ from hypothesis import given
 class TestSubmitters(TestCase):
 
     @given(job_rec = Model.Jobs(),
-           job_code = jobs())
+           job_code = jobs(),
+           run = Model.Runs())
     @with_database
-    def test_submit(self, job_rec, job_code):
+    def test_submit(self, job_rec, job_code, run):
+        run.save()
+        job_rec.run = run
+        job_rec.save()
         _run(job_code.submitter._submit(job_rec))
\ No newline at end of file
